@@ -23,16 +23,16 @@ from aliyunsdkimgsearch.endpoint import endpoint_data
 class CreateImageDbRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'imgsearch', '2020-03-20', 'CreateImageDb','imgsearch')
+		RpcRequest.__init__(self, 'imgsearch', '2020-03-20', 'CreateImageDb')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Name(self):
+	def get_Name(self): # String
 		return self.get_body_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_body_params('Name', Name)
\ No newline at end of file
+	def set_Name(self, Name):  # String
+		self.add_body_params('Name', Name)
