@@ -23,9 +23,11 @@ from aliyunsdkimgsearch.endpoint import endpoint_data
 class ListImageDbsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'imgsearch', '2020-03-20', 'ListImageDbs','imgsearch')
+		RpcRequest.__init__(self, 'imgsearch', '2020-03-20', 'ListImageDbs')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
